function [ ConDia,InefFact ] = convstats(thetadraws,m)
% Computes Geweke's (1992) convergence diagonstic and inefficiency factor
% for a vector of draws from the Gibbs sampler. m is the lag truncation
% parameter for computing zero frequency spectral densities.

N = length(thetadraws);

Na = round(0.1*N);
Nb = round(0.5*N);

thetaAdraws = thetadraws(1:Na);
thetaBdraws = thetadraws(N-Nb+1:N);
        
thetaAbar = mean(thetaAdraws);
thetaBbar = mean(thetaBdraws);
        
thetadraws = thetadraws - mean(thetadraws);
thetaAdraws = thetaAdraws - thetaAbar;
thetaBdraws = thetaBdraws - thetaBbar;
        
vtheta = (1/N)*(thetadraws(1:N)'*thetadraws(1:N));
vartheta = vtheta;

vthetaA = (1/Na)*(thetaAdraws(1:Na)'*thetaAdraws(1:Na));
vthetaB = (1/Nb)*(thetaBdraws(1:Nb)'*thetaBdraws(1:Nb));
        
Stheta0 = vtheta;
SthetaA0 = vthetaA;
SthetaB0 = vthetaB;
        
for j = 1:m

    vtheta = (1/(N-j))*(thetadraws(1+j:N)'*thetadraws(1:N-j));
    vthetaA = (1/(Na-j))*(thetaAdraws(1+j:Na)'*thetaAdraws(1:Na-j));
    vthetaB = (1/(Nb-j))*(thetaBdraws(1+j:Nb)'*thetaBdraws(1:Nb-j));

    Stheta0 = Stheta0 + 2*(1-(j/(m+1)))*vtheta;
    SthetaA0 = SthetaA0 + 2*(1-(j/(m+1)))*vthetaA;
    SthetaB0 = SthetaB0 + 2*(1-(j/(m+1)))*vthetaB;

end

ConDia = (thetaAbar-thetaBbar)/sqrt((SthetaA0/Na+SthetaB0/Nb));
InefFact = Stheta0/vartheta;