function [ Bhat,VB,alphahat,Valpha,sigmahat,Vsigma ] = cpvarest(cpvardata)
% Estimates a constant parameter version of the three-variable VAR to
% calibrate priors for the version with time-varying parameters.

global q Ra

% =========================================================================
% Estimate reduced-form parameters via OLS
% =========================================================================

Tcp = length(cpvardata(:,1)) - q;

Yt = cpvardata(q+1:Tcp+q,:);

Xt = [ ones(Tcp,1) zeros(Tcp,3*q) ];
for p = 1:q
    Xt(:,2+3*(p-1):4+3*(p-1)) = cpvardata(q+1-p:Tcp+q-p,:);
end

XpXinv = eye(1+3*q)/(Xt'*Xt);

Bhat = XpXinv*(Xt'*Yt);

ut = Yt - Xt*Bhat;

OmegaOLS = (1/(Tcp-1-3*q))*(ut'*ut);

Bhat = Bhat(:);

VB = kron(OmegaOLS,XpXinv);

% =========================================================================
% Recover estimates of A and Sigma from Omega
% =========================================================================

OmegaMLE = (1/Tcp)*(ut'*ut);

AinvSig = chol(OmegaMLE,'lower');

Sigmahat = diag((diag(AinvSig)));
Ahat = Sigmahat/AinvSig;

alphahat = [ Ahat(2,1) ; Ahat(3,1) ; Ahat(3,2) ];
sigmahat = diag(Sigmahat);

% =========================================================================
% Compute standard errors for A and Sigma
% =========================================================================

Rsig = zeros(9,3);

Rsig(1,1) = 1;
Rsig(5,2) = 1;
Rsig(9,3) = 1;

K = zeros(9,9);

K(1,1) = 1;
K(2,4) = 1;
K(3,7) = 1;
K(4,2) = 1;
K(5,5) = 1;
K(6,8) = 1;
K(7,3) = 1;
K(8,6) = 1;
K(9,9) = 1;

Ialphasigma1 = [ kron(Ahat\Sigmahat,eye(3)/Sigmahat) ; ...
                 -kron(eye(3),eye(3)/Sigmahat) ];

Ialphasigma = Ialphasigma1*(eye(9)+K)*Ialphasigma1';

dasig = [ Ra' zeros(3,9) ; zeros(3,9) Rsig' ];

Iasig = dasig*Ialphasigma*dasig';

Vasig = (1/Tcp)*eye(6)/Iasig;

Valpha = Vasig(1:3,1:3);
Vsigma = Vasig(4:6,4:6);