% Used by tvpvarsim.m to initial states for the Gibbs sampling algorithm.
% The program will return to this step if explosive draws are discarded
% and the first attempt at initialization does not allow the algorithm to
% continue.

notinit = 1;

while notinit
    
    notinit = 0;

    Q = invwishdraw(scaleQ,dfQ);

    S1 = invwishdraw(scaleS1,dfS1);
    S2 = invwishdraw(scaleS2,dfS2);

    S = [ S1 zeros(1,2) ; zeros(2,1) S2 ];

    W11 = invwishdraw(scaleW(1,1),dfW);
    W22 = invwishdraw(scaleW(2,2),dfW);
    W33 = invwishdraw(scaleW(3,3),dfW);

    W = diag([ W11 W22 W33 ]);

    ATmat = zeros(3,T);
    lSigTmat = zeros(3,T);

    ATmat(:,1) = mvndraw(muA,scaleA+S);
    lSigTmat(:,1) = mvndraw(mulSig,scalelSig+W);

    for t = 2:T

        ATmat(:,t) = mvndraw(ATmat(:,t-1),S);
        lSigTmat(:,t) = mvndraw(lSigTmat(:,t-1),W);

    end
    
    Bnotdone = 1;
        
    BdrawNum = 1;

    while Bnotdone && (BdrawNum <= maxBdraws)

        BTdraw = Bdraw(ATmat,lSigTmat,Q); 

        if discard == 1

            noeigviol = 1;
            t = 1;

            while noeigviol && (t <= T)

                Bmatt = reshape(BTdraw(:,t),1+3*q,3);

                BigBt = [ Bmatt(2:1+3*q,:)' ; eye(3*(q-1)) zeros(3*(q-1),3) ];

                if max(abs(eig(BigBt))) <= 1

                    t = t + 1;

                else

                    noeigviol = 0;

                end

            end

            if noeigviol

                Bnotdone = 0;

            else

                BdrawNum = BdrawNum + 1;

            end

        else

            Bnotdone = 0;

        end

    end

    if Bnotdone

        notinit = 1;

    else

        BTmat = BTdraw;

        if idscheme == 1

            ATmat = Adraw(BTmat,lSigTmat,S);

            lSigTmat = lSigdraw(BTmat,ATmat,lSigTmat,W);
            
            ASnotdone = 0;

        else

            ASnotdone = 1;

            ASdrawNum = 1;

            while ASnotdone && (ASdrawNum <= 1000)

                ATdraw = Adraw(BTmat,lSigTmat,S);

                lSigTdraw = lSigdraw(BTmat,ATdraw,lSigTmat,W);

                Xtilde = randn(3);
                [ Qx,Rx ] = qr(Xtilde);
                for j = 1:3
                    if Rx(j,j) < 0
                        Qx(:,j) = -Qx(:,j);
                    end
                end

                nosignviol = 1;
                t = 1;

                while nosignviol && (t <= T)

                    Avect = Ra*ATdraw(:,t) + ra;
                    Amatt = reshape(Avect,3,3);

                    Sigmatt = diag(exp(lSigTdraw(:,t)));

                    Lt = Amatt\Sigmatt;

                    Ltildat = Lt*Qx';

                    signchecks = -gsign*Ltildat(1,1)*Ltildat(2,1);

                    signcheckd1 = Ltildat(1,2)*Ltildat(3,2);
                    signcheckd2 = gsign*Ltildat(2,2)*Ltildat(3,2);

                    signcheckm1 = -Ltildat(1,3)*Ltildat(3,3);
                    signcheckm2 = -gsign*Ltildat(2,3)*Ltildat(3,3);

                    if (signchecks>0) && (signcheckd1>0) && (signcheckd2>0) && (signcheckm1>0) && (signcheckm2>0)
                        t = t + 1;
                    else
                        nosignviol = 0;
                    end

                end

                if nosignviol

                    ATmat = ATdraw;
                    lSigTmat = lSigTdraw;

                    ASnotdone = 0;

                else

                    ASdrawNum = ASdrawNum + 1;

                end

            end

        end

        if ASnotdone 

            notinit = 1;

        else

            nuTmat = BTmat(:,2:T) - BTmat(:,1:T-1);

            zetaTmat = ATmat(:,2:T) - ATmat(:,1:T-1);

            etaTmat = lSigTmat(:,2:T) - lSigTmat(:,1:T-1);

            SigmaB = scaleQ;

            SigmaA1 = scaleS1;

            SigmaA2 = scaleS2;

            SigmaSig = scaleW;

            for t = 1:T-1

                SigmaB = SigmaB + nuTmat(:,t)*nuTmat(:,t)';

                SigmaA1 = SigmaA1 + zetaTmat(1,t)*zetaTmat(1,t)';

                SigmaA2 = SigmaA2 + zetaTmat(2:3,t)*zetaTmat(2:3,t)';

                SigmaSig = SigmaSig + diag(diag(etaTmat(:,t)*etaTmat(:,t)'));

            end

            Q = invwishdraw(SigmaB,dfQ+T);

            S1 = invwishdraw(SigmaA1,dfS1+T);

            S2 = invwishdraw(SigmaA2,dfS2+T);

            S = [ S1 zeros(1,2) ; zeros(2,1) S2 ];

            W11 = invwishdraw(SigmaSig(1,1),dfW+T);

            W22 = invwishdraw(SigmaSig(2,2),dfW+T);

            W33 = invwishdraw(SigmaSig(3,3),dfW+T);

            W = diag([ W11 W22 W33 ]);

        end

    end
    
end
 