function lSigTmat = lSigdraw(BTmat,ATmat,lSigTold,W)
% Draws a new volatility state using the Kim-Shephard-Chib,
% Stroud-Muller-Polson, and Carter-Kohn algorithms.

global ydata xdata T Ra ra mulSig scalelSig qvec mvec v2vec
global sigMH sigaccept sigreject

sTmat = zeros(3,T);

ystmat = zeros(3,T);

ysstmat = zeros(3,T);

for t = 1:T
    
    yt = ydata(t,:)';
    
    Xpt = kron(eye(3),xdata(t,:));
    
    Bt = BTmat(:,t);
    
    Atvec = Ra*ATmat(:,t) + ra;
    
    At = reshape(Atvec,3,3);
    
    yst = At*(yt-Xpt*Bt);
    
    ystmat(:,t) = yst;
    
    ysst = log(yst.^2+0.001);
    
    ysstmat(:,t) = ysst;
    
    ht = lSigTold(:,t);
    
    for i = 1:3
        
        probvec = qvec.*normalpdf(ysst(i)*ones(7,1),2*ht(i)*ones(7,1)+mvec-1.2704,v2vec);
        
        probvec = probvec./(sum(probvec));
        
        cumprobvecu = cumsum(probvec);
        
        cumprobvecl = [ -0.0001 ; cumprobvecu(1:6) ];
        
        sitdraw = rand(1,1);
        
        sitcheck = and(sitdraw>cumprobvecl,sitdraw<=cumprobvecu);
        
        [~,sTmat(i,t)] = max(sitcheck); 
        
    end
    
end

httmat = zeros(3,T);

Pttmat = zeros(9,T);

htt = mulSig;

Ptt = scalelSig;

for t = 1:T
    
    xt = ysstmat(:,t) - mvec(sTmat(:,t)) + 1.2704;
    
    Vt = diag(v2vec(sTmat(:,t)));
        
    htl = htt;
    
    Ptl = Ptt + W;
    
    Kt = 2*Ptl/(4*Ptl+Vt);
    
    htt = htl + Kt*(xt-2*htl);
    
    Ptt = Ptl - 2*Kt*Ptl;
    
    httmat(:,t) = htt;
    
    Pttmat(:,t) = Ptt(:);
    
end

lSigTdraw = zeros(3,T);

h = httmat(:,T);

VVp = reshape(Pttmat(:,T),3,3);

lSigTdraw(:,T) = mvndraw(h,VVp);

for j = 1:T-1
    
    htt = httmat(:,T-j);
    
    Ptt = reshape(Pttmat(:,T-j),3,3);
    
    h = htt + Ptt/(Ptt+W)*(lSigTdraw(:,T-j+1)-htt);
    
    VVp = Ptt - Ptt/(Ptt+W)*Ptt;

    lSigTdraw(:,T-j) = mvndraw(h,VVp);
    
end

if sigMH == 1
    
   lalpha = 0;
   
   for t = 1:T
       
       lDetdraw = sum(lSigTdraw(:,t));
       
       lDetold = sum(lSigTold(:,t));
       
       Sigdrawt = diag(exp(lSigTdraw(:,t)));
       
       Sigoldt = diag(exp(lSigTold(:,t)));
       
       quaddraw = Sigdrawt\ystmat(:,t);
       
       quadold = Sigoldt\ystmat(:,t);
       
       lalpha = lalpha - lDetdraw - (1/2)*(quaddraw'*quaddraw) ...
                  + lDetold + (1/2)*(quadold'*quadold);
       
       for i = 1:3
           
           probdraw = sum(qvec.*normalpdf(ysstmat(i,t)*ones(7,1),2*lSigTdraw(i,t)*ones(7,1)+mvec-1.2704,v2vec));
           
           probold = sum(qvec.*normalpdf(ysstmat(i,t)*ones(7,1),2*lSigTold(i,t)*ones(7,1)+mvec-1.2704,v2vec));
          
           lalpha = lalpha + log(probold) - log(probdraw);
           
       end
       
   end
       
   alphastar = rand(1);

   if alphastar < exp(lalpha)

       lSigTmat = lSigTdraw;
       sigaccept = sigaccept + 1;

   else

       lSigTmat = lSigTold;
       sigreject = sigreject + 1;

   end
       
else

    lSigTmat = lSigTdraw;
    sigaccept = sigaccept + 1;
    
end
