% poststats: Summarizes results found by tvpvarsim, structure, and
% counterfact for a three-variable VAR with time-varying parameters and
% stochastic volatility by reporting median and 16/84 percentiles of the
% posterior distributions for key parameters.
%
% Note that for the purposes of estimating structural shocks, computing 
% impulse responses, and running counterfactual simulations, the structural
% model has been normalized based on the direction of each shock:
% expansionary or contractionary. Here, for the purposes of characterizing
% the posterior distribution of the impact coefficients, the model is
% re-normalized so that the matrix C has +1s along its diagonal.

% =========================================================================
% Load results from posterior simulation
% =========================================================================

load tvpvarout

lindex = round(0.1587*nstores);
mindex = round(0.5*nstores);
uindex = round((1-0.1587)*nstores);

% =========================================================================
% Sort draws from posterior distribution
% =========================================================================

alphagpSort = sort(alphagpT);
alpharpSort = sort(alpharpT);
alphargSort = sort(alphargT);

sigpSort = sort(sigpT);
siggSort = sort(siggT);
sigrSort = sort(sigrT);

mupSort = sort(mupT);
mugSort = sort(mugT);
murSort = sort(murT);

cpgSort = sort(cppT.*cpgT);
cprSort = sort(cppT.*cprT);
cgpSort = sort(cggT.*cgpT);
cgrSort = sort(cggT.*cgrT);
crpSort = sort(crrT.*crpT);
crgSort = sort(crrT.*crgT);

deltapSort = sort(deltapT);
deltagSort = sort(deltagT);
deltarSort = sort(deltarT);

gammarrSort = sort(crrT.*gammarrT);
gammarpSort = sort(gammarpT);
gammargSort = sort(gammargT);

deltaxipSort = sort(deltapT.*xipT);
deltaxigSort = sort(deltagT.*xigT);
deltaxirSort = sort(deltarT.*xirT);

psimp75Sort = sort(psimp75);
gsimp75Sort = sort(gsimp75);
rsimp75Sort = sort(rsimp75);

pdimp75Sort = sort(pdimp75);
gdimp75Sort = sort(gdimp75);
rdimp75Sort = sort(rdimp75);

pmimp75Sort = sort(pmimp75);
gmimp75Sort = sort(gmimp75);
rmimp75Sort = sort(rmimp75);

psimp90Sort = sort(psimp90);
gsimp90Sort = sort(gsimp90);
rsimp90Sort = sort(rsimp90);

pdimp90Sort = sort(pdimp90);
gdimp90Sort = sort(gdimp90);
rdimp90Sort = sort(rdimp90);

pmimp90Sort = sort(pmimp90);
gmimp90Sort = sort(gmimp90);
rmimp90Sort = sort(rmimp90);

psimp00Sort = sort(psimp00);
gsimp00Sort = sort(gsimp00);
rsimp00Sort = sort(rsimp00);

pdimp00Sort = sort(pdimp00);
gdimp00Sort = sort(gdimp00);
rdimp00Sort = sort(rdimp00);

pmimp00Sort = sort(pmimp00);
gmimp00Sort = sort(gmimp00);
rmimp00Sort = sort(rmimp00);

psimp07Sort = sort(psimp07);
gsimp07Sort = sort(gsimp07);
rsimp07Sort = sort(rsimp07);

pdimp07Sort = sort(pdimp07);
gdimp07Sort = sort(gdimp07);
rdimp07Sort = sort(rdimp07);

pmimp07Sort = sort(pmimp07);
gmimp07Sort = sort(gmimp07);
rmimp07Sort = sort(rmimp07);

psvdec75Sort = sort(psvdec75);
gsvdec75Sort = sort(gsvdec75);
rsvdec75Sort = sort(rsvdec75);

pdvdec75Sort = sort(pdvdec75);
gdvdec75Sort = sort(gdvdec75);
rdvdec75Sort = sort(rdvdec75);

pmvdec75Sort = sort(pmvdec75);
gmvdec75Sort = sort(gmvdec75);
rmvdec75Sort = sort(rmvdec75);

psvdec90Sort = sort(psvdec90);
gsvdec90Sort = sort(gsvdec90);
rsvdec90Sort = sort(rsvdec90);

pdvdec90Sort = sort(pdvdec90);
gdvdec90Sort = sort(gdvdec90);
rdvdec90Sort = sort(rdvdec90);

pmvdec90Sort = sort(pmvdec90);
gmvdec90Sort = sort(gmvdec90);
rmvdec90Sort = sort(rmvdec90);

psvdec00Sort = sort(psvdec00);
gsvdec00Sort = sort(gsvdec00);
rsvdec00Sort = sort(rsvdec00);

pdvdec00Sort = sort(pdvdec00);
gdvdec00Sort = sort(gdvdec00);
rdvdec00Sort = sort(rdvdec00);

pmvdec00Sort = sort(pmvdec00);
gmvdec00Sort = sort(gmvdec00);
rmvdec00Sort = sort(rmvdec00);

psvdec07Sort = sort(psvdec07);
gsvdec07Sort = sort(gsvdec07);
rsvdec07Sort = sort(rsvdec07);

pdvdec07Sort = sort(pdvdec07);
gdvdec07Sort = sort(gdvdec07);
rdvdec07Sort = sort(rdvdec07);

pmvdec07Sort = sort(pmvdec07);
gmvdec07Sort = sort(gmvdec07);
rmvdec07Sort = sort(rmvdec07);

pdata0Sort = sort(pdata0);
gdata0Sort = sort(gdata0);
rdata0Sort = sort(rdata0);

pdata1Sort = sort(pdata1);
gdata1Sort = sort(gdata1);
rdata1Sort = sort(rdata1);

pdata2Sort = sort(pdata2);
gdata2Sort = sort(gdata2);
rdata2Sort = sort(rdata2);

pdata3Sort = sort(pdata3);
gdata3Sort = sort(gdata3);
rdata3Sort = sort(rdata3);

pdata4Sort = sort(pdata4);
gdata4Sort = sort(gdata4);
rdata4Sort = sort(rdata4);

pdata5Sort = sort(pdata5);
gdata5Sort = sort(gdata5);
rdata5Sort = sort(rdata5);

pdata6Sort = sort(pdata6);
gdata6Sort = sort(gdata6);
rdata6Sort = sort(rdata6);

pdata7Sort = sort(pdata7);
gdata7Sort = sort(gdata7);
rdata7Sort = sort(rdata7);

% =========================================================================
% Find 16 percentiles
% =========================================================================

alphagp_16 = alphagpSort(lindex,:)';
alpharp_16 = alpharpSort(lindex,:)';
alpharg_16 = alphargSort(lindex,:)';

sigp_16 = sigpSort(lindex,:)';
sigg_16 = siggSort(lindex,:)';
sigr_16 = sigrSort(lindex,:)';

mup_16 = mupSort(lindex,:)';
mug_16 = mugSort(lindex,:)';
mur_16 = murSort(lindex,:)';

cpg_16 = cpgSort(lindex,:)';
cpr_16 = cprSort(lindex,:)';
cgp_16 = cgpSort(lindex,:)';
cgr_16 = cgrSort(lindex,:)';
crp_16 = crpSort(lindex,:)';
crg_16 = crgSort(lindex,:)';

deltap_16 = deltapSort(lindex,:)';
deltag_16 = deltagSort(lindex,:)';
deltar_16 = deltarSort(lindex,:)';

gammarr_16 = gammarrSort(lindex,:)';
gammarp_16 = gammarpSort(lindex,:)';
gammarg_16 = gammargSort(lindex,:)';

deltaxip_16 = deltaxipSort(lindex,:)';
deltaxig_16 = deltaxigSort(lindex,:)';
deltaxir_16 = deltaxirSort(lindex,:)';

psimp75_16 = psimp75Sort(lindex,:)';
gsimp75_16 = gsimp75Sort(lindex,:)';
rsimp75_16 = rsimp75Sort(lindex,:)';

pdimp75_16 = pdimp75Sort(lindex,:)';
gdimp75_16 = gdimp75Sort(lindex,:)';
rdimp75_16 = rdimp75Sort(lindex,:)';

pmimp75_16 = pmimp75Sort(lindex,:)';
gmimp75_16 = gmimp75Sort(lindex,:)';
rmimp75_16 = rmimp75Sort(lindex,:)';

psimp90_16 = psimp90Sort(lindex,:)';
gsimp90_16 = gsimp90Sort(lindex,:)';
rsimp90_16 = rsimp90Sort(lindex,:)';

pdimp90_16 = pdimp90Sort(lindex,:)';
gdimp90_16 = gdimp90Sort(lindex,:)';
rdimp90_16 = rdimp90Sort(lindex,:)';

pmimp90_16 = pmimp90Sort(lindex,:)';
gmimp90_16 = gmimp90Sort(lindex,:)';
rmimp90_16 = rmimp90Sort(lindex,:)';

psimp00_16 = psimp00Sort(lindex,:)';
gsimp00_16 = gsimp00Sort(lindex,:)';
rsimp00_16 = rsimp00Sort(lindex,:)';

pdimp00_16 = pdimp00Sort(lindex,:)';
gdimp00_16 = gdimp00Sort(lindex,:)';
rdimp00_16 = rdimp00Sort(lindex,:)';

pmimp00_16 = pmimp00Sort(lindex,:)';
gmimp00_16 = gmimp00Sort(lindex,:)';
rmimp00_16 = rmimp00Sort(lindex,:)';

psimp07_16 = psimp07Sort(lindex,:)';
gsimp07_16 = gsimp07Sort(lindex,:)';
rsimp07_16 = rsimp07Sort(lindex,:)';

pdimp07_16 = pdimp07Sort(lindex,:)';
gdimp07_16 = gdimp07Sort(lindex,:)';
rdimp07_16 = rdimp07Sort(lindex,:)';

pmimp07_16 = pmimp07Sort(lindex,:)';
gmimp07_16 = gmimp07Sort(lindex,:)';
rmimp07_16 = rmimp07Sort(lindex,:)';

psvdec75_16 = psvdec75Sort(lindex,:)';
gsvdec75_16 = gsvdec75Sort(lindex,:)';
rsvdec75_16 = rsvdec75Sort(lindex,:)';

pdvdec75_16 = pdvdec75Sort(lindex,:)';
gdvdec75_16 = gdvdec75Sort(lindex,:)';
rdvdec75_16 = rdvdec75Sort(lindex,:)';

pmvdec75_16 = pmvdec75Sort(lindex,:)';
gmvdec75_16 = gmvdec75Sort(lindex,:)';
rmvdec75_16 = rmvdec75Sort(lindex,:)';

psvdec90_16 = psvdec90Sort(lindex,:)';
gsvdec90_16 = gsvdec90Sort(lindex,:)';
rsvdec90_16 = rsvdec90Sort(lindex,:)';

pdvdec90_16 = pdvdec90Sort(lindex,:)';
gdvdec90_16 = gdvdec90Sort(lindex,:)';
rdvdec90_16 = rdvdec90Sort(lindex,:)';

pmvdec90_16 = pmvdec90Sort(lindex,:)';
gmvdec90_16 = gmvdec90Sort(lindex,:)';
rmvdec90_16 = rmvdec90Sort(lindex,:)';

psvdec00_16 = psvdec00Sort(lindex,:)';
gsvdec00_16 = gsvdec00Sort(lindex,:)';
rsvdec00_16 = rsvdec00Sort(lindex,:)';

pdvdec00_16 = pdvdec00Sort(lindex,:)';
gdvdec00_16 = gdvdec00Sort(lindex,:)';
rdvdec00_16 = rdvdec00Sort(lindex,:)';

pmvdec00_16 = pmvdec00Sort(lindex,:)';
gmvdec00_16 = gmvdec00Sort(lindex,:)';
rmvdec00_16 = rmvdec00Sort(lindex,:)';

psvdec07_16 = psvdec07Sort(lindex,:)';
gsvdec07_16 = gsvdec07Sort(lindex,:)';
rsvdec07_16 = rsvdec07Sort(lindex,:)';

pdvdec07_16 = pdvdec07Sort(lindex,:)';
gdvdec07_16 = gdvdec07Sort(lindex,:)';
rdvdec07_16 = rdvdec07Sort(lindex,:)';

pmvdec07_16 = pmvdec07Sort(lindex,:)';
gmvdec07_16 = gmvdec07Sort(lindex,:)';
rmvdec07_16 = rmvdec07Sort(lindex,:)';

pdata0_16 = pdata0Sort(lindex,:)';
gdata0_16 = gdata0Sort(lindex,:)';
rdata0_16 = rdata0Sort(lindex,:)';

pdata1_16 = pdata1Sort(lindex,:)';
gdata1_16 = gdata1Sort(lindex,:)';
rdata1_16 = rdata1Sort(lindex,:)';

pdata2_16 = pdata2Sort(lindex,:)';
gdata2_16 = gdata2Sort(lindex,:)';
rdata2_16 = rdata2Sort(lindex,:)';

pdata3_16 = pdata3Sort(lindex,:)';
gdata3_16 = gdata3Sort(lindex,:)';
rdata3_16 = rdata3Sort(lindex,:)';

pdata4_16 = pdata4Sort(lindex,:)';
gdata4_16 = gdata4Sort(lindex,:)';
rdata4_16 = rdata4Sort(lindex,:)';

pdata5_16 = pdata5Sort(lindex,:)';
gdata5_16 = gdata5Sort(lindex,:)';
rdata5_16 = rdata5Sort(lindex,:)';

pdata6_16 = pdata6Sort(lindex,:)';
gdata6_16 = gdata6Sort(lindex,:)';
rdata6_16 = rdata6Sort(lindex,:)';

pdata7_16 = pdata7Sort(lindex,:)';
gdata7_16 = gdata7Sort(lindex,:)';
rdata7_16 = rdata7Sort(lindex,:)';

% =========================================================================
% Find medians
% =========================================================================

alphagp_50 = alphagpSort(mindex,:)';
alpharp_50 = alpharpSort(mindex,:)';
alpharg_50 = alphargSort(mindex,:)';

sigp_50 = sigpSort(mindex,:)';
sigg_50 = siggSort(mindex,:)';
sigr_50 = sigrSort(mindex,:)';

mup_50 = mupSort(mindex,:)';
mug_50 = mugSort(mindex,:)';
mur_50 = murSort(mindex,:)';

cpg_50 = cpgSort(mindex,:)';
cpr_50 = cprSort(mindex,:)';
cgp_50 = cgpSort(mindex,:)';
cgr_50 = cgrSort(mindex,:)';
crp_50 = crpSort(mindex,:)';
crg_50 = crgSort(mindex,:)';

deltap_50 = deltapSort(mindex,:)';
deltag_50 = deltagSort(mindex,:)';
deltar_50 = deltarSort(mindex,:)';

gammarr_50 = gammarrSort(mindex,:)';
gammarp_50 = gammarpSort(mindex,:)';
gammarg_50 = gammargSort(mindex,:)';

deltaxip_50 = deltaxipSort(mindex,:)';
deltaxig_50 = deltaxigSort(mindex,:)';
deltaxir_50 = deltaxirSort(mindex,:)';

psimp75_50 = psimp75Sort(mindex,:)';
gsimp75_50 = gsimp75Sort(mindex,:)';
rsimp75_50 = rsimp75Sort(mindex,:)';

pdimp75_50 = pdimp75Sort(mindex,:)';
gdimp75_50 = gdimp75Sort(mindex,:)';
rdimp75_50 = rdimp75Sort(mindex,:)';

pmimp75_50 = pmimp75Sort(mindex,:)';
gmimp75_50 = gmimp75Sort(mindex,:)';
rmimp75_50 = rmimp75Sort(mindex,:)';

psimp90_50 = psimp90Sort(mindex,:)';
gsimp90_50 = gsimp90Sort(mindex,:)';
rsimp90_50 = rsimp90Sort(mindex,:)';

pdimp90_50 = pdimp90Sort(mindex,:)';
gdimp90_50 = gdimp90Sort(mindex,:)';
rdimp90_50 = rdimp90Sort(mindex,:)';

pmimp90_50 = pmimp90Sort(mindex,:)';
gmimp90_50 = gmimp90Sort(mindex,:)';
rmimp90_50 = rmimp90Sort(mindex,:)';

psimp00_50 = psimp00Sort(mindex,:)';
gsimp00_50 = gsimp00Sort(mindex,:)';
rsimp00_50 = rsimp00Sort(mindex,:)';

pdimp00_50 = pdimp00Sort(mindex,:)';
gdimp00_50 = gdimp00Sort(mindex,:)';
rdimp00_50 = rdimp00Sort(mindex,:)';

pmimp00_50 = pmimp00Sort(mindex,:)';
gmimp00_50 = gmimp00Sort(mindex,:)';
rmimp00_50 = rmimp00Sort(mindex,:)';

psimp07_50 = psimp07Sort(mindex,:)';
gsimp07_50 = gsimp07Sort(mindex,:)';
rsimp07_50 = rsimp07Sort(mindex,:)';

pdimp07_50 = pdimp07Sort(mindex,:)';
gdimp07_50 = gdimp07Sort(mindex,:)';
rdimp07_50 = rdimp07Sort(mindex,:)';

pmimp07_50 = pmimp07Sort(mindex,:)';
gmimp07_50 = gmimp07Sort(mindex,:)';
rmimp07_50 = rmimp07Sort(mindex,:)';

psvdec75_50 = psvdec75Sort(mindex,:)';
gsvdec75_50 = gsvdec75Sort(mindex,:)';
rsvdec75_50 = rsvdec75Sort(mindex,:)';

pdvdec75_50 = pdvdec75Sort(mindex,:)';
gdvdec75_50 = gdvdec75Sort(mindex,:)';
rdvdec75_50 = rdvdec75Sort(mindex,:)';

pmvdec75_50 = pmvdec75Sort(mindex,:)';
gmvdec75_50 = gmvdec75Sort(mindex,:)';
rmvdec75_50 = rmvdec75Sort(mindex,:)';

psvdec90_50 = psvdec90Sort(mindex,:)';
gsvdec90_50 = gsvdec90Sort(mindex,:)';
rsvdec90_50 = rsvdec90Sort(mindex,:)';

pdvdec90_50 = pdvdec90Sort(mindex,:)';
gdvdec90_50 = gdvdec90Sort(mindex,:)';
rdvdec90_50 = rdvdec90Sort(mindex,:)';

pmvdec90_50 = pmvdec90Sort(mindex,:)';
gmvdec90_50 = gmvdec90Sort(mindex,:)';
rmvdec90_50 = rmvdec90Sort(mindex,:)';

psvdec00_50 = psvdec00Sort(mindex,:)';
gsvdec00_50 = gsvdec00Sort(mindex,:)';
rsvdec00_50 = rsvdec00Sort(mindex,:)';

pdvdec00_50 = pdvdec00Sort(mindex,:)';
gdvdec00_50 = gdvdec00Sort(mindex,:)';
rdvdec00_50 = rdvdec00Sort(mindex,:)';

pmvdec00_50 = pmvdec00Sort(mindex,:)';
gmvdec00_50 = gmvdec00Sort(mindex,:)';
rmvdec00_50 = rmvdec00Sort(mindex,:)';

psvdec07_50 = psvdec07Sort(mindex,:)';
gsvdec07_50 = gsvdec07Sort(mindex,:)';
rsvdec07_50 = rsvdec07Sort(mindex,:)';

pdvdec07_50 = pdvdec07Sort(mindex,:)';
gdvdec07_50 = gdvdec07Sort(mindex,:)';
rdvdec07_50 = rdvdec07Sort(mindex,:)';

pmvdec07_50 = pmvdec07Sort(mindex,:)';
gmvdec07_50 = gmvdec07Sort(mindex,:)';
rmvdec07_50 = rmvdec07Sort(mindex,:)';

pdata0_50 = pdata0Sort(mindex,:)';
gdata0_50 = gdata0Sort(mindex,:)';
rdata0_50 = rdata0Sort(mindex,:)';

pdata1_50 = pdata1Sort(mindex,:)';
gdata1_50 = gdata1Sort(mindex,:)';
rdata1_50 = rdata1Sort(mindex,:)';

pdata2_50 = pdata2Sort(mindex,:)';
gdata2_50 = gdata2Sort(mindex,:)';
rdata2_50 = rdata2Sort(mindex,:)';

pdata3_50 = pdata3Sort(mindex,:)';
gdata3_50 = gdata3Sort(mindex,:)';
rdata3_50 = rdata3Sort(mindex,:)';

pdata4_50 = pdata4Sort(mindex,:)';
gdata4_50 = gdata4Sort(mindex,:)';
rdata4_50 = rdata4Sort(mindex,:)';

pdata5_50 = pdata5Sort(mindex,:)';
gdata5_50 = gdata5Sort(mindex,:)';
rdata5_50 = rdata5Sort(mindex,:)';

pdata6_50 = pdata6Sort(mindex,:)';
gdata6_50 = gdata6Sort(mindex,:)';
rdata6_50 = rdata6Sort(mindex,:)';

pdata7_50 = pdata7Sort(mindex,:)';
gdata7_50 = gdata7Sort(mindex,:)';
rdata7_50 = rdata7Sort(mindex,:)';

% =========================================================================
% Find 84 percentiles
% =========================================================================

alphagp_84 = alphagpSort(uindex,:)';
alpharp_84 = alpharpSort(uindex,:)';
alpharg_84 = alphargSort(uindex,:)';

sigp_84 = sigpSort(uindex,:)';
sigg_84 = siggSort(uindex,:)';
sigr_84 = sigrSort(uindex,:)';

mup_84 = mupSort(uindex,:)';
mug_84 = mugSort(uindex,:)';
mur_84 = murSort(uindex,:)';

cpg_84 = cpgSort(uindex,:)';
cpr_84 = cprSort(uindex,:)';
cgp_84 = cgpSort(uindex,:)';
cgr_84 = cgrSort(uindex,:)';
crp_84 = crpSort(uindex,:)';
crg_84 = crgSort(uindex,:)';

deltap_84 = deltapSort(uindex,:)';
deltag_84 = deltagSort(uindex,:)';
deltar_84 = deltarSort(uindex,:)';

gammarr_84 = gammarrSort(uindex,:)';
gammarp_84 = gammarpSort(uindex,:)';
gammarg_84 = gammargSort(uindex,:)';

deltaxip_84 = deltaxipSort(uindex,:)';
deltaxig_84 = deltaxigSort(uindex,:)';
deltaxir_84 = deltaxirSort(uindex,:)';

psimp75_84 = psimp75Sort(uindex,:)';
gsimp75_84 = gsimp75Sort(uindex,:)';
rsimp75_84 = rsimp75Sort(uindex,:)';

pdimp75_84 = pdimp75Sort(uindex,:)';
gdimp75_84 = gdimp75Sort(uindex,:)';
rdimp75_84 = rdimp75Sort(uindex,:)';

pmimp75_84 = pmimp75Sort(uindex,:)';
gmimp75_84 = gmimp75Sort(uindex,:)';
rmimp75_84 = rmimp75Sort(uindex,:)';

psimp90_84 = psimp90Sort(uindex,:)';
gsimp90_84 = gsimp90Sort(uindex,:)';
rsimp90_84 = rsimp90Sort(uindex,:)';

pdimp90_84 = pdimp90Sort(uindex,:)';
gdimp90_84 = gdimp90Sort(uindex,:)';
rdimp90_84 = rdimp90Sort(uindex,:)';

pmimp90_84 = pmimp90Sort(uindex,:)';
gmimp90_84 = gmimp90Sort(uindex,:)';
rmimp90_84 = rmimp90Sort(uindex,:)';

psimp00_84 = psimp00Sort(uindex,:)';
gsimp00_84 = gsimp00Sort(uindex,:)';
rsimp00_84 = rsimp00Sort(uindex,:)';

pdimp00_84 = pdimp00Sort(uindex,:)';
gdimp00_84 = gdimp00Sort(uindex,:)';
rdimp00_84 = rdimp00Sort(uindex,:)';

pmimp00_84 = pmimp00Sort(uindex,:)';
gmimp00_84 = gmimp00Sort(uindex,:)';
rmimp00_84 = rmimp00Sort(uindex,:)';

psimp07_84 = psimp07Sort(uindex,:)';
gsimp07_84 = gsimp07Sort(uindex,:)';
rsimp07_84 = rsimp07Sort(uindex,:)';

pdimp07_84 = pdimp07Sort(uindex,:)';
gdimp07_84 = gdimp07Sort(uindex,:)';
rdimp07_84 = rdimp07Sort(uindex,:)';

pmimp07_84 = pmimp07Sort(uindex,:)';
gmimp07_84 = gmimp07Sort(uindex,:)';
rmimp07_84 = rmimp07Sort(uindex,:)';

psvdec75_84 = psvdec75Sort(uindex,:)';
gsvdec75_84 = gsvdec75Sort(uindex,:)';
rsvdec75_84 = rsvdec75Sort(uindex,:)';

pdvdec75_84 = pdvdec75Sort(uindex,:)';
gdvdec75_84 = gdvdec75Sort(uindex,:)';
rdvdec75_84 = rdvdec75Sort(uindex,:)';

pmvdec75_84 = pmvdec75Sort(uindex,:)';
gmvdec75_84 = gmvdec75Sort(uindex,:)';
rmvdec75_84 = rmvdec75Sort(uindex,:)';

psvdec90_84 = psvdec90Sort(uindex,:)';
gsvdec90_84 = gsvdec90Sort(uindex,:)';
rsvdec90_84 = rsvdec90Sort(uindex,:)';

pdvdec90_84 = pdvdec90Sort(uindex,:)';
gdvdec90_84 = gdvdec90Sort(uindex,:)';
rdvdec90_84 = rdvdec90Sort(uindex,:)';

pmvdec90_84 = pmvdec90Sort(uindex,:)';
gmvdec90_84 = gmvdec90Sort(uindex,:)';
rmvdec90_84 = rmvdec90Sort(uindex,:)';

psvdec00_84 = psvdec00Sort(uindex,:)';
gsvdec00_84 = gsvdec00Sort(uindex,:)';
rsvdec00_84 = rsvdec00Sort(uindex,:)';

pdvdec00_84 = pdvdec00Sort(uindex,:)';
gdvdec00_84 = gdvdec00Sort(uindex,:)';
rdvdec00_84 = rdvdec00Sort(uindex,:)';

pmvdec00_84 = pmvdec00Sort(uindex,:)';
gmvdec00_84 = gmvdec00Sort(uindex,:)';
rmvdec00_84 = rmvdec00Sort(uindex,:)';

psvdec07_84 = psvdec07Sort(uindex,:)';
gsvdec07_84 = gsvdec07Sort(uindex,:)';
rsvdec07_84 = rsvdec07Sort(uindex,:)';

pdvdec07_84 = pdvdec07Sort(uindex,:)';
gdvdec07_84 = gdvdec07Sort(uindex,:)';
rdvdec07_84 = rdvdec07Sort(uindex,:)';

pmvdec07_84 = pmvdec07Sort(uindex,:)';
gmvdec07_84 = gmvdec07Sort(uindex,:)';
rmvdec07_84 = rmvdec07Sort(uindex,:)';

pdata0_84 = pdata0Sort(uindex,:)';
gdata0_84 = gdata0Sort(uindex,:)';
rdata0_84 = rdata0Sort(uindex,:)';

pdata1_84 = pdata1Sort(uindex,:)';
gdata1_84 = gdata1Sort(uindex,:)';
rdata1_84 = rdata1Sort(uindex,:)';

pdata2_84 = pdata2Sort(uindex,:)';
gdata2_84 = gdata2Sort(uindex,:)';
rdata2_84 = rdata2Sort(uindex,:)';

pdata3_84 = pdata3Sort(uindex,:)';
gdata3_84 = gdata3Sort(uindex,:)';
rdata3_84 = rdata3Sort(uindex,:)';

pdata4_84 = pdata4Sort(uindex,:)';
gdata4_84 = gdata4Sort(uindex,:)';
rdata4_84 = rdata4Sort(uindex,:)';

pdata5_84 = pdata5Sort(uindex,:)';
gdata5_84 = gdata5Sort(uindex,:)';
rdata5_84 = rdata5Sort(uindex,:)';

pdata6_84 = pdata6Sort(uindex,:)';
gdata6_84 = gdata6Sort(uindex,:)';
rdata6_84 = rdata6Sort(uindex,:)';

pdata7_84 = pdata7Sort(uindex,:)';
gdata7_84 = gdata7Sort(uindex,:)';
rdata7_84 = rdata7Sort(uindex,:)';